import React from 'react';
import { UseHighlighter } from './highlighter';

interface SimpleMarkdownProps {
    content: string;
    className?: string;
    ctexTclass?: string;
    imageHeight?: number;
    theme?: string;
    codeBlockTheme?: string;
}

const icons = {
    NOTE: (
        <svg width="24" height="24" fill="currentColor" viewBox="0 0 24 24" className="mr-2">
            <circle cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="2" fill="none" />
            <text x="12" y="16" textAnchor="middle" fontSize="12" fontWeight="bold" fill="currentColor">i</text>
        </svg>
    ),
    TIP: (
        <svg width="24" height="24" fill="currentColor" viewBox="0 0 24 24" className="mr-2">
            <path d="M12 2a7 7 0 0 0-7 7c0 2.2 1.2 4.2 3 5.3V17h8v-2.7c1.8-1.1 3-3.1 3-5.3a7 7 0 0 0-7-7zm0 14h-2v-2h2v2zm0-4h-2V9h2v3z" />
        </svg>
    ),
    IMPORTANT: (
        <svg width="24" height="24" fill="currentColor" viewBox="0 0 24 24" className="mr-2">
            <rect width="20" height="16" x="2" y="4" rx="2" stroke="currentColor" strokeWidth="2" fill="none" />
            <text x="12" y="14" textAnchor="middle" fontSize="12" fontWeight="bold" fill="currentColor">i</text>
        </svg>
    ),
    WARNING: (
        <svg width="24" height="24" fill="currentColor" viewBox="0 0 24 24" className="mr-2">
            <path d="M12 2L2 22h20L12 2zm0 16h-2v-2h2v2zm0-4h-2v-4h2v4z" />
        </svg>
    ),
    CAUTION: (
        <svg width="24" height="24" fill="currentColor" viewBox="0 0 24 24" className="mr-2">
            <circle cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="2" fill="none" />
            <text x="12" y="16" textAnchor="middle" fontSize="12" fontWeight="bold" fill="currentColor">!</text>
        </svg>
    )
};

const SimpleMarkdown: React.FC<SimpleMarkdownProps> = ({
    content,
    className = 'dark:prose-invert',
    ctexTclass = "my-2",
    imageHeight = 400,
    theme = 'light',
    codeBlockTheme = "bg-[#fdf6e3] dark:bg-[#2d353b]"
}) => {
    const parseMarkdown = (md: string): string => {
        const lines = md.split('\n');
        let inCodeBlock = false;
        let inTable = false;
        let html = '';
        let currentParagraph = '';
        let inList = false;
        let listType = '';
        let currentCodeLanguage = '';

        const flushParagraph = () => {
            if (currentParagraph) {
                html += `<p class="${ctexTclass}">${currentParagraph.trim()}</p>`;
                currentParagraph = '';
            }
        };

        const flushList = () => {
            if (inList) {
                html += `</${listType}>`;
                inList = false;
                listType = '';
            }
        };

        const flushTable = () => {
            if (inTable) {
                html += '</tbody></table>';
                inTable = false;
            }
        };

        const parseInline = (text: string): string => {
            text = text.replace(/\*\*(.*?)\*\*/g, '<strong>$1</strong>');
            text = text.replace(/\*(.*?)\*/g, '<em>$1</em>');
            text = text.replace(/`([^`]+)`/g, '<code class="bg-gray-100 dark:bg-gray-800 px-1 rounded">$1</code>');
            text = text.replace(/<iframe.*?src=["']([^"']+)["'].*?><\/iframe>/g, `<iframe width="100%" height="${imageHeight}" src="$1" frameborder="0" allowfullscreen></iframe>`);
            text = text.replace(/\[([^\]]+)\]\(([^)]+)\s*"?(.*?)"?\)/g, '<a href="$2" title="$3" target="_blank" class="text-blue-500 hover:underline">$1</a>');
            text = text.replace(/\[([^\]]+)\]\(([^)]+)\)/g, '<a href="$2" target="_blank" class="text-blue-500 hover:underline">$1</a>');

            return text;
        };

        const highlightCode = (code: string, language: string) => {
            const codeComponent = UseHighlighter({ content: code, lang: language, theme: theme });
            return `${codeComponent}`;
        };

        let codeLines: string[] = [];
        lines.forEach((line) => {
            if (line.trim().startsWith('```')) {
                flushParagraph();
                flushList();
                flushTable();
                inCodeBlock = !inCodeBlock;
                currentCodeLanguage = inCodeBlock ? line.trim().slice(3).toLowerCase() : '';
                html += inCodeBlock
                    ? `<pre><code class="language-${currentCodeLanguage} ${codeBlockTheme} block p-2 rounded-md">`
                    : '</code></pre>';
            } else if (inCodeBlock) {
                html += highlightCode(line, currentCodeLanguage);
            } else if (/^>\s*\[!(NOTE|TIP|IMPORTANT|WARNING|CAUTION)\]/i.test(line)) {
                const match = line.match(/^>\s*\[!(NOTE|TIP|IMPORTANT|WARNING|CAUTION)\]\s*(.*)/i);
                const type = match![1].toUpperCase();
                const content = parseInline(match![2]);
                const styles = {
                    NOTE: 'bg-blue-50 border-blue-400 text-blue-800',
                    TIP: 'bg-green-50 border-green-400 text-green-800',
                    IMPORTANT: 'bg-purple-50 border-purple-400 text-purple-800',
                    WARNING: 'bg-yellow-50 border-yellow-400 text-yellow-800',
                    CAUTION: 'bg-red-50 border-red-400 text-red-800'
                }[type];

                html += `
                    <div class="flex items-start border-l-4 p-4 my-2 ${styles}">
                        ${icons[type].props.children}
                        <div>${content}</div>
                    </div>`;
            } else if (/^\|(.+)\|$/.test(line)) {
                flushParagraph();
                flushList();
                if (!inTable) {
                    html += '<table class="table-auto border-collapse my-4"><tbody>';
                    inTable = true;
                }
                const cells = line.split('|').slice(1, -1).map(cell => `<td class="border px-2">${parseInline(cell.trim())}</td>`).join('');
                html += `<tr>${cells}</tr>`;
            } else {
                currentParagraph += `${parseInline(line)} `;
            }
        });

        flushParagraph();
        flushList();
        flushTable();
        return html;
    };

    return <div className={`prose ${className}`} dangerouslySetInnerHTML={{ __html: parseMarkdown(content) }} />;
};

export { SimpleMarkdown };

